"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createColorizeColors = exports.colorizeClassName = exports.provideCssVariables = exports.themeProjectKeys = exports.themeKeys = void 0;
const logical_not_1 = require("logical-not");
exports.themeKeys = [
    'background',
    'backgroundBright',
    'backgroundTint',
    'text',
    'textTint',
];
exports.themeProjectKeys = ['colors'];
const head = document.querySelector('head');
const body = document.querySelector('body');
const providedCssVariablesMap = {};
let prevThemeClassName = '';
let prevThemeProjectClassName = '';
function provideCssVariables({ theme, themeKey, themeProjectKey, }) {
    const themeClassName = `plmt-theme-${kebabCase(themeKey)}`;
    if ((0, logical_not_1.not)(themeClassName in providedCssVariablesMap)) {
        const cssVariables = [];
        Object.entries(theme).forEach(([key, source]) => {
            if (exports.themeKeys.includes(key)) {
                const name = kebabCase(key);
                if (Array.isArray(source))
                    source.forEach((value, i) => cssVariables.push({
                        name: `--${name}-${i}`,
                        value,
                    }));
                else
                    cssVariables.push({ name: `--${name}`, value: source });
            }
        });
        addStyles(themeClassName, [
            { className: themeClassName, cssProperties: cssVariables },
        ]);
    }
    prevThemeClassName = switchClassName(prevThemeClassName, themeClassName);
    const themeProjectClassName = `plmt-project-${themeProjectKey}`;
    if ((0, logical_not_1.not)(themeProjectClassName in providedCssVariablesMap)) {
        const cssVariables = theme.colors.map((value, i) => ({
            name: `--plmt-color-${i}`,
            value,
        }));
        addStyles(themeProjectClassName, [
            { className: themeProjectClassName, cssProperties: cssVariables },
        ]);
    }
    prevThemeProjectClassName = switchClassName(prevThemeProjectClassName, themeProjectClassName);
    if ((0, logical_not_1.not)('colorize' in providedCssVariablesMap)) {
        const items = [];
        theme.colorize.forEach((colors, i) => {
            colors.forEach((value, j) => items.push({
                className: colorizeClassName(i, j),
                cssProperties: [
                    {
                        name: 'background-color',
                        value,
                    },
                ],
            }));
        });
        addStyles(`colorize`, items);
    }
}
exports.provideCssVariables = provideCssVariables;
function colorizeClassName(i, j) {
    return `plmt-colorize-${i}-${j}`;
}
exports.colorizeClassName = colorizeClassName;
const range10 = [...Array(10)].map((_, i) => i);
function createColorizeColors(source) {
    return source.map((color) => {
        const [r, g, b] = parseColor(color);
        return range10.map((i) => `rgba(${r},${g},${b},${++i > 9 ? '1' : `0.${i}`})`);
    });
}
exports.createColorizeColors = createColorizeColors;
const color6hex = /([0-9abcdef]{2})([0-9abcdef]{2})([0-9abcdef]{2})/i;
const color3hex = /([0-9abcdef])([0-9abcdef])([0-9abcdef])/i;
function parseColor(source) {
    const [, r, g, b] = source.match(color6hex) ||
        source.match(color3hex) || [, '0', '0', '0'];
    return [parseInt(r, 16), parseInt(g, 16), parseInt(b, 16)];
}
function addStyles(name, items) {
    const style = document.createElement('style');
    providedCssVariablesMap[name] = style;
    const styleParts = [];
    items.forEach(({ className, cssProperties }) => {
        styleParts.push('.', className, '{\n');
        cssProperties.forEach(({ name, value }) => styleParts.push('  ', name, ': ', value, ';\n'));
        styleParts.push('}\n');
    });
    style.innerHTML = styleParts.join('');
    head.append(style);
}
function switchClassName(prev, next) {
    if (prev)
        body.classList.remove(prev);
    body.classList.add(next);
    return next;
}
function kebabCase(source) {
    const chars = Array(source.length);
    for (let i = 0, lim = source.length; i < lim; i++) {
        const char = source.charAt(i);
        const lowerCaseChar = char.toLowerCase();
        chars[i] = char === lowerCaseChar ? char : '-' + lowerCaseChar;
    }
    return chars.join('');
}
