"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.provideDataTo = void 0;
const config_1 = require("./config");
const widget_1 = require("./widget");
const defaultDataSettingsMethods = {
    setFilter() { },
    removeFilterAt() { },
    setSort() { },
    removeSortAt() { },
    interact() { },
};
function provideDataTo(widget, { dataOptionsMap, viewOptions }, dataSettingsMethods = defaultDataSettingsMethods) {
    const widgetMultiData = {};
    const widgetDataSettingsMap = {};
    const formatters = window.parent['format']?.[widget.uid] || {};
    widget.viewSettings = {};
    Object.values(dataOptionsMap).forEach(({ data_option, rows, total }) => {
        widgetMultiData[data_option.key] = rows;
        const columns = data_option.dataset.columns_id.map((source) => ({
            type: source.base_type,
            id: source.id,
            path: source.path,
            format: formatters[source.path] || ((value) => value),
            name: source.name,
        }));
        const columnsByBlock = {};
        const filters = [];
        const sort = [];
        const colorize = [];
        data_option.blocks.forEach((block) => {
            if (block.block_type === config_1.ConfigDataBlockType_Server.Drilldown)
                return;
            switch (block.key) {
                case config_1.blockFilterKey:
                    block.columns.forEach(({ column_id, action, value }) => {
                        const column = columns.find(({ id }) => column_id === id);
                        filters.push({
                            column,
                            method: action,
                            value,
                        });
                    });
                    break;
                case config_1.blockSortKey:
                    block.columns.forEach(({ column_id, value: direction }) => {
                        const column = columns.find(({ id }) => column_id === id);
                        sort.push({
                            column,
                            direction,
                        });
                    });
                    break;
                case config_1.blockColorizeKey:
                    block.columns.forEach(({ value }) => {
                        const source = value;
                        const column = columns.find(({ id }) => source.columnId === id);
                        colorize.push((0, widget_1.createColorizeItem)(widget, column, source));
                    });
                    break;
                default:
                    columnsByBlock[block.key] = block.columns.map(({ column_id }) => {
                        return columns.find((item) => item.id === column_id);
                    });
            }
        });
        const dataSettingsItem = {
            columns,
            columnsByBlock,
            filters,
            sort,
            colorize,
            total,
            limit: data_option.limit_rows,
            offset: data_option.offset,
            ...{
                ...dataSettingsMethods,
                interact: dataSettingsMethods.interact.bind(data_option),
            },
            ...getDataSettingsEvents(widget, data_option.key),
        };
        widgetDataSettingsMap[data_option.key] = dataSettingsItem;
    });
    if (widget_1.widgetDefaultKey in widgetDataSettingsMap) {
        Object.assign(widget, {
            data: widgetMultiData[widget_1.widgetDefaultKey],
            dataSettings: widgetDataSettingsMap[widget_1.widgetDefaultKey],
        });
    }
    else {
        Object.assign(widget, {
            data: widgetMultiData,
            dataSettings: widgetDataSettingsMap,
        });
    }
    widget.viewSettings = {};
    viewOptions.forEach(({ key, value }) => (widget.viewSettings[key] = value));
}
exports.provideDataTo = provideDataTo;
function getDataSettingsEvents(widget, key) {
    const dataSettings = key === widget_1.widgetDefaultKey
        ? widget.dataSettings
        : widget.dataSettings[key];
    if (dataSettings)
        return {
            events: dataSettings.events,
        };
    else
        return {
            events: {},
        };
}
