"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dispatchChangeOtherFilters = exports.createColorizeItem = exports.widgetDefaultKey = void 0;
const data_1 = require("../data");
exports.widgetDefaultKey = 'ffed0a4d-4a9d-417f-b502-eb50142c6956';
function createColorizeItem(widget, column, source) {
    const max = +source.max || 0;
    const min = +source.min || 0;
    const threshold = +source.threshold || 0;
    const colorAbove = source.colorAbove;
    const colorBelow = source.colorBelow;
    const deltaAbove = max - threshold;
    const deltaBelow = threshold - min;
    return {
        column,
        getColor(value) {
            value = +value || 0;
            if (value > max || value < min)
                return color();
            if (value >= threshold) {
                const colors = widget.theme.colorize[colorAbove] || [];
                if (value === max)
                    return color(colors[colors.length - 1]);
                const i = Math.floor(((value - threshold) / deltaAbove) * colors.length);
                return color(colors[i]);
            }
            else {
                const colors = widget.theme.colorize[colorBelow] || [];
                if (value === min)
                    return color(colors[colors.length - 1]);
                const i = Math.floor(((threshold - value) / deltaBelow) * colors.length);
                return color(colors[i]);
            }
        },
    };
}
exports.createColorizeItem = createColorizeItem;
function color(source) {
    return source || 'transparent';
}
function dispatchChangeOtherFilters(widget, source) {
    source.forEach(({ column_id, value }) => {
        const dataSettings = getDataSettingsByColumnId(widget, column_id);
        if (dataSettings &&
            typeof dataSettings.events.onOtherFilterChange === 'function') {
            const column = dataSettings.columns.find(({ id }) => id === column_id);
            if (column)
                dataSettings.events.onOtherFilterChange({
                    column,
                    method: data_1.FilterMethod.InList,
                    value,
                });
        }
    });
}
exports.dispatchChangeOtherFilters = dispatchChangeOtherFilters;
function getDataSettingsByColumnId(widget, columnId) {
    if (Array.isArray(widget.data))
        return widget.dataSettings;
    for (let dataSettings of Object.values(widget.dataSettings))
        if (dataSettings.columns.find(({ id }) => id === columnId))
            return dataSettings;
    return null;
}
